Copyright (c) 2019 Nico Piatkowski

pxpy
====
The python library for discrete pairwise undirected graphical models.

**FULL-FLEDGED README COMING SOON**

Changelog
=========
* 1.0a10: Optimized library build
* 1.0a9:  Enabled sampling with observations; Fixed parameter name in marginal inference
* 1.0a8:  Fixed maximum a posteriori estimation; Added custom graph construction
* 1.0a7:  Multiple minor fixes; enabled marginal inference with observations; enabled minimal statistics
* 1.0a6:  Added manual model creation; enabled training data with missing values
* 1.0a5:  Fixed model management
* 1.0a4:  Added model access in regularization and proximal hooks
* 1.0a3:  Lower GLIBC requirement + removed libgomp dependency (linux)
* 1.0a2:  Python 3.5 compatibility
* 1.0a1:  Initial release
